@@ -6,12 +6,9 @@ struct jellyfish_state {
     PyObject *unicodedata_normalize;
 };
 
-#if PY_MAJOR_VERSION >= 3
 #define GETSTATE(m) ((struct jellyfish_state*)PyModule_GetState(m))
-#else
-#define GETSTATE(m) (&_state)
-static struct jellyfish_state _state;
-#endif
+#define UTF8_BYTES(s) (PyBytes_AS_STRING(s))
+#define NO_BYTES_ERR_STR "str argument expected"
 
 #ifdef _MSC_VER
 #define INLINE __inline
@@ -19,16 +16,6 @@ static struct jellyfish_state _state;
 #define INLINE inline
 #endif
 
-#if PY_MAJOR_VERSION >= 3
-#define UTF8_BYTES(s) (PyBytes_AS_STRING(s))
-#define NO_BYTES_ERR_STR "str argument expected"
-#else
-#define UTF8_BYTES(s) (PyString_AS_STRING(s))
-#define NO_BYTES_ERR_STR "unicode argument expected"
-#endif
-
-#define UNSUPPORTED_CODEPOINT "Encountered unsupported code point in string."
-
 
 /* Returns a new reference to a PyString (python < 3) or
  * PyBytes (python >= 3.0).
@@ -155,11 +142,6 @@ static PyObject* jellyfish_damerau_levenshtein_distance(PyObject *self,
         PyErr_NoMemory();
         return NULL;
     }
-    else if (result == -2) {
-        PyErr_SetString(PyExc_ValueError, UNSUPPORTED_CODEPOINT);
-        return NULL;
-    }
-
     return Py_BuildValue("i", result);
 }
 
@@ -391,7 +373,6 @@ static PyMethodDef jellyfish_methods[] = {
     {NULL, NULL, 0, NULL}
 };
 
-#if PY_MAJOR_VERSION >= 3
 #define INITERROR return NULL
 
 static struct PyModuleDef moduledef = {
@@ -407,20 +388,9 @@ static struct PyModuleDef moduledef = {
 };
 
 PyObject* PyInit_cjellyfish(void)
-#else
-
-#define INITERROR return
-
-PyMODINIT_FUNC initcjellyfish(void)
-#endif
 {
     PyObject *unicodedata;
-
-#if PY_MAJOR_VERSION >= 3
     PyObject *module = PyModule_Create(&moduledef);
-#else
-    PyObject *module = Py_InitModule("jellyfish.cjellyfish", jellyfish_methods);
-#endif
 
     if (module == NULL) {
         INITERROR;
@@ -435,7 +405,5 @@ PyMODINIT_FUNC initcjellyfish(void)
         PyObject_GetAttrString(unicodedata, "normalize");
     Py_DECREF(unicodedata);
 
-#if PY_MAJOR_VERSION >= 3
     return module;
-#endif
 }
